@@ -26,9 +26,9 @@ class discrete_signal:
             self.number_steps = int(self.data.shape[1])
 
         self.frequency = kwargs.get('frequency', 1)
-        if not(isinstance(self.frequency, int)):
-            raise ValueError("Frequency needs to be a positive integer.")
+        if not(isinstance(self.frequency, float) or isinstance(self.frequency, int)):
+            raise ValueError("Frequency needs to be a positive integer or float.")
         if not(self.frequency > 0):
-            raise ValueError("Frequency needs to be a positive integer.")
+            raise ValueError("Frequency needs to be a positive integer or float.")
 
         self.total_time = float((self.number_steps - 1) / self.frequency)
